<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Inc
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php global $inc_settings;
$inc_settings = inc_get_option_defaults(); ?>

<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'inc' ); ?></a>
	<?php if (has_header_video() || has_header_image()) {
		the_custom_header_markup();
	} ?>

	<header id="masthead" class="site-header">
		<?php 
		$inc_phone_no = $inc_settings['inc_phone_no'];
		$inc_email_id = $inc_settings['inc_email_id'];
		$inc_location = $inc_settings['inc_location'];
		$inc_skype = $inc_settings['inc_skype'];

		if ( ($inc_phone_no !== '' || $inc_email_id !== '' || $inc_location !== '' || $inc_skype !== '') || ($inc_settings['inc_social_profiles'] != '' && $inc_settings['inc_infobar_social'] === 0) ) { ?>
			<div class="info-bar">
				<div class="container<?php echo ($inc_settings['inc_header_fluid'] === 1 && $inc_settings['inc_site_layout'] === 'wide') ? "-fluid" : "";?>">
	            	<div class="row gutter-0">
	            		<?php if ($inc_phone_no !== '' || $inc_email_id !== '' || $inc_location !== '' || $inc_skype !== '') { ?>
							<div class="col-md contact-section">
								<?php inc_contact_info(); ?>
							</div><!-- .contact-section -->
	         			<?php } ?>
						<?php if ($inc_settings['inc_social_profiles'] != '' && $inc_settings['inc_infobar_social'] === 0) { ?>
							<div class="col-md-auto social-profile-section <?php echo ($inc_phone_no === '' && $inc_email_id === '' && $inc_location === '' && $inc_skype === '') ? "ml-auto" : "";?>">
								<?php echo esc_html(inc_social_profiles()); ?>
							</div><!-- .social-profile-section -->
						<?php } ?>
					</div><!-- .row -->
          		</div><!-- .container-fluid -->
        	</div><!-- .infobar -->
        <?php } ?>
		<nav class="navbar navbar-expand-lg">
			<div class="container<?php echo ( $inc_settings['inc_header_fluid'] === 1 && $inc_settings['inc_site_layout'] === 'wide' ) ? "-fluid" : "";?>">
				<div class="site-branding navbar-brand">
					<?php
					the_custom_logo();
					if ( is_page_template('templates/business-template.php') || is_home() ) :
						?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php
					else :
						?>
						<h2 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h2>
						<?php
					endif;
					$inc_description = get_bloginfo( 'description', 'display' );
					if ( $inc_description || is_customize_preview() ) :
						?>
						<p class="site-description"><?php echo $inc_description; /* WPCS: xss ok. */ ?></p>
					<?php endif; ?>
				</div><!-- .site-branding .navbar-brand -->
				<button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarCollapse" aria-controls="navbarCollapse" aria-expanded="false" aria-label="<?php esc_attr_e('Toggle navigation', 'inc'); ?>"></button>
				<div class="collapse navbar-collapse" id="navbarCollapse">
					<div id="site-navigation" class="main-navigation ml-lg-auto d-lg-flex <?php echo ($inc_settings['inc_nav_uppercase'] == 1) ? "nav-uppercase" : "";?>" role="navigation">
						<?php
						if (has_nav_menu('primary')) {
							wp_nav_menu( array(
								'theme_location' 	=> 'primary',
								'container'			=> '',
								'items_wrap'		=> '<ul class="nav-menu navbar-nav d-lg-block">%3$s</ul>',
							) );
						} else {
							wp_page_menu( array(
								'before' 		=> '<ul class="nav-menu navbar-nav d-lg-block">',
								'after' 			=> '</ul>',
							) );
						}
						?>
							<div class="d-none d-lg-flex">
								<span class="search-toggle"></span>
							</div><!-- .navbar-search -->
					</div><!-- #site-navigation .main-navigation -->
				</div><!-- .navbar-collapse -->
			</div><!-- .container -->
		</nav><!-- .navbar -->
		<?php if ( is_front_page() && $inc_settings['inc_disable_slider'] !== 1 ) {
			if (function_exists('inc_pass_slider_effect_cycle_parameters')) {
				inc_pass_slider_effect_cycle_parameters();
			}
			if (function_exists('inc_featured_sliders')) {
				inc_featured_sliders();
			}
		}
		if ( !is_front_page() && !is_page_template('templates/business-template.php') ) { ?>
			<div class="page-header">
				<div class="page-title-wrap"<?php if ( $inc_settings['inc_page_title_img'] != '' ){ ?> style="background-image:url('<?php echo esc_url($inc_settings['inc_page_title_img']);?>');" <?php } ?>>
					<div class="container">
						<?php if (is_archive()) {
							the_archive_title('<h1 class="page-title">', '</h1>');
							the_archive_description('<div class="archive-description">','</div>');
						} elseif (is_home()) { ?>
							<h2 class="page-title"><?php echo get_the_title(get_option('page_for_posts')); ?> </h2>
						<?php } elseif (is_404()) { ?>
							<h1 class="page-title"><?php esc_html_e('Page NOT Found','inc'); ?> </h1>
						<?php } elseif (is_search()) { ?>
							<h1 class="page-title"><?php printf(esc_html__('Search Results for: %s', 'inc'), '<span>' . get_search_query() . '</span>'); ?></h1>
						<?php } else {
							the_title('<h1 class="page-title">','</h1>' );
						} ?>
					</div><!-- .container -->
				</div><!-- .page-title-wrap -->
				<?php if ( !is_front_page() && function_exists('bcn_display_list') ) { ?>
					<div class="breadcrumb">
						<div class="container">
							<?php bcn_display(); ?>
						</div>
					</div><!-- .breadcrumb-bar -->
				<?php } ?>
			</div><!-- .page-header -->
		<?php } ?>
	</header><!-- #masthead -->
	<div id="content" class="site-content">
		<?php if ( !is_page_template('templates/business-template.php') ) { ?>
			<div class="container">
				<div class="row justify-content-center">
		<?php } ?>
