<?php
/**
 * Inc Theme Customizer
 *
 * @package Inc
 */

function inc_support_register($wp_customize){
	class Inc_Customize_Inc_Support extends WP_Customize_Control {
		public function render_content() { ?>
		<div class="theme-info">
			<a title="<?php esc_attr_e( 'Review Inc', 'inc' ); ?>" href="<?php echo esc_url( 'https://wordpress.org/support/view/theme-reviews/inc' ); ?>" target="_blank">
				<?php esc_html_e( 'Rate Inc', 'inc' ); ?>
			</a>
			<a href="<?php echo esc_url( 'https://www.themehorse.com/theme-instruction/inc/' ); ?>" title="<?php esc_attr_e( 'Inc Theme Instructions', 'inc' ); ?>" target="_blank">
			<?php esc_html_e( 'Theme Instructions', 'inc' ); ?>
			</a>
			<a href="<?php echo esc_url( 'https://www.themehorse.com/support-forum/' ); ?>" title="<?php esc_attr_e( 'Support Forum', 'inc' ); ?>" target="_blank">
			<?php esc_html_e( 'Support Forum', 'inc' ); ?>
			</a>
			<a href="<?php echo esc_url( 'https://www.themehorse.com/preview/inc' ); ?>" title="<?php esc_attr_e( 'Inc Demo', 'inc' ); ?>" target="_blank">
			<?php esc_html_e( 'View Demo', 'inc' ); ?>
			</a>
		</div>
		<?php
		}
	}
}
add_action('customize_register', 'inc_support_register');

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function inc_customize_register( $wp_customize ) {
	global $inc_settings;
	$inc_settings = inc_get_option_defaults();

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'inc_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'inc_customize_partial_blogdescription',
		) );
	}

	$wp_customize->get_control( 'background_color' )->active_callback = 'inc_is_sitelayout_is_narrow';
	$wp_customize->get_control( 'background_image' )->description = __('Effects only if set Site Layout to Boxed.','inc');

	// Section => Inc Support
	$wp_customize->add_section('inc_support', array(
		'title'					=> __('Inc Support', 'inc'),
	));
	$wp_customize->add_setting('inc_support', array(
		'default'				=> false,
		'capability'			=> 'edit_theme_options',
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));
	$wp_customize->add_control( new Inc_Customize_Inc_Support( $wp_customize, 'inc_support', array(
		'label'					=> __('Inc Support','inc'),
		'section'				=> 'inc_support'
	) ) );

	// Section => Background Image > Control > Title Background Image
	$wp_customize->add_setting( 'inc_page_title_img',array(
		'default'				=> '',
		'sanitize_callback'		=> 'esc_url_raw',
		'capability' 			=> 'edit_theme_options'
	));
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'inc_page_title_img', array(
		'label'					=> __('Title Background Image', 'inc'),
		'section'				=> 'background_image',
	) ) );

	// Panel => Layout
	$wp_customize->add_panel('inc_layout_options', array(
		'title'					=> __('Layout', 'inc'),
		'priority'				=> 121,
	) );

	// Section => Site Layout
	$wp_customize->add_section( 'inc_site_layout_section', array(
		'title' 					=> __('Site Layout','inc'),
		'panel'					=> 'inc_layout_options'
	) );
	$wp_customize->add_setting('inc_site_layout', array(
		'default'				=> 'wide',
		'sanitize_callback'	=> 'inc_sanitize_choices',
		'capability' 			=> 'edit_theme_options'
	) );
	$wp_customize->add_control('inc_site_layout', array(
		'section'				=> 'inc_site_layout_section',
		'type'					=> 'radio',
		'checked'				=> 'checked',
		'choices'				=> array(
			'wide'					=> __('Fluid','inc'),
			'narrow'					=> __('Boxed','inc'),
		),
	) );

	// Section => Content Layout
	$wp_customize->add_section( 'inc_content_layout_section', array(
		'title' 					=> __('Content Layout','inc'),
		'panel'					=> 'inc_layout_options'
	) );
	$wp_customize->add_setting('inc_content_layout', array(
		'default'				=> 'right',
		'sanitize_callback'	=> 'inc_sanitize_choices',
		'capability' 			=> 'edit_theme_options'
	) );
	$wp_customize->add_control('inc_content_layout', array(
		'description'			=> __('Below options are global setting. Set individual layout from specific page/ post.','inc'),
		'section'				=> 'inc_content_layout_section',
		'type'					=> 'radio',
		'checked'				=> 'checked',
		'choices'				=> array(
			'right'					=> __('Right Sidebar','inc'),
			'left'					=> __('Left Sidebar','inc'),
			'nosidebar'				=> __('No Sidebar','inc'),
			'fullwidth'				=> __('No Sidebar Full Width','inc'),
		),
	) );

	// Section => Header
	$wp_customize->add_section('inc_custom_header_setting', array(
		'title'					=> __('Header', 'inc'),
		'priority'				=> 122,
	) );
	$wp_customize->add_setting('inc_phone_no', array(
		'default'					=> '',
		'sanitize_callback'			=> 'inc_sanitize_phone',
	));
	$wp_customize->add_control('inc_phone_no', array(
		'label'						=> __('Contact Info Bar', 'inc'),
		'description'				=> __('Enter Phone Number Only', 'inc'),
		'section'					=> 'inc_custom_header_setting',
		'type'						=> 'text',
	));
	$wp_customize->add_setting('inc_email_id', array(
		'default'					=> '',
		'sanitize_callback'			=> 'sanitize_email',
	));
	$wp_customize->add_control('inc_email_id', array(
		'description'				=> __('Email Address Only', 'inc'),
		'section'					=> 'inc_custom_header_setting',
		'type'						=> 'text',
	));
	$wp_customize->add_setting('inc_location', array(
		'default'					=> '',
		'sanitize_callback'			=> 'sanitize_text_field',
	));
	$wp_customize->add_control('inc_location', array(
		'description'				=> __('Location Only', 'inc'),
		'section'					=> 'inc_custom_header_setting',
		'type'						=> 'text',
	));
	$wp_customize->add_setting('inc_location_url', array(
		'default'					=> '',
		'sanitize_callback'			=> 'esc_url_raw',
	));
	$wp_customize->add_control('inc_location_url', array(
		'description'				=> __('Location Url Only', 'inc'),
		'section'					=> 'inc_custom_header_setting',
		'type'						=> 'text',
	));
	$wp_customize->add_setting('inc_skype', array(
		'default'					=> '',
		'sanitize_callback'			=> 'sanitize_text_field',
	));
	$wp_customize->add_control('inc_skype', array(
		'description'				=> __('Skype ID Only', 'inc'),
		'section'					=> 'inc_custom_header_setting',
		'type'						=> 'text',
	));
	$wp_customize->add_setting('inc_infobar_social', array(
		'default'				=> 0,
		'sanitize_callback'		=> 'inc_sanitize_integer',
	) );
	$wp_customize->add_control( 'inc_infobar_social', array(
		'label'					=> __('Hide Social Profiles', 'inc'),
		'section'				=> 'inc_custom_header_setting',
		'type'					=> 'checkbox',
		'active_callback'		=> 'inc_is_social_profiles_set'
	) );
	$wp_customize->add_setting( 'inc_nav_uppercase', array(
		'default'				=> 0,
		'sanitize_callback'		=> 'inc_sanitize_integer',
	) );
	$wp_customize->add_control( 'inc_nav_uppercase', array(
		'label'					=> __('Navigation Uppercase', 'inc'),
		'section'				=> 'inc_custom_header_setting',
		'type'					=> 'checkbox'
	) );
	$wp_customize->add_setting( 'inc_header_fluid', array(
		'default'				=> 0,
		'sanitize_callback'		=> 'inc_sanitize_integer',
		'capability' 			=> 'edit_theme_options'
	) );
	$wp_customize->add_control( 'inc_header_fluid', array(
		'label'					=> __('Header Fluid', 'inc'),
		'section'				=> 'inc_custom_header_setting',
		'type'					=> 'checkbox',
		'active_callback'		=> 'inc_is_sitelayout_is_wide'
	) );

	// Section => Social Profiles
	$wp_customize->add_section('inc_social_profiles_setting', array(
		'title'					=> __('Social Profiles', 'inc'),
		'priority'				=> 123,
	) );
	$wp_customize->add_setting('inc_social_profiles', array(
		'default'				=> '',
		'sanitize_callback'		=> 'inc_sanitize_social_links',
		'capability' 			=> 'edit_theme_options'
	) );
	$wp_customize->add_control( 'inc_social_profiles', array(
		'description' 			=> __('Add the full link to your Social Profiles. Seperate with comma ,','inc'),
		'section'				=> 'inc_social_profiles_setting',
		'type'					=> 'textarea'
	) );

	// Panel => Slider Options
	$wp_customize->add_panel('inc_slider_options', array(
		'title'					=> __('Slider Options', 'inc'),
		'priority'				=> 124,
	) );
	// Section => Slider Settings
	$wp_customize->add_section( 'inc_slider_options_setting', array(
		'title'					=> __('Slider Settings', 'inc'),
		'panel'					=> 'inc_slider_options'
	));
	$wp_customize->add_setting( 'inc_disable_slider', array(
		'default'					=> 1,
		'sanitize_callback'			=> 'inc_sanitize_integer',
		'capability' 				=> 'edit_theme_options'
	));
	$wp_customize->add_control( 'inc_disable_slider', array(
		'label'						=> __('Disable Slider', 'inc'),
		'section'					=> 'inc_slider_options_setting',
		'type'						=> 'checkbox',
	));
	$wp_customize->add_setting('inc_slider_quantity', array(
		'default'					=> '4',
		'sanitize_callback'			=> 'inc_sanitize_delay_transition',
		'capability' 				=> 'edit_theme_options'
	));
	$wp_customize->add_control('inc_slider_quantity', array(
		'label'						=> __('Number of Slides', 'inc'),
		'section'					=> 'inc_slider_options_setting',
		'active_callback'			=> 'inc_is_enable_slider_set',
		'type'						=> 'text',
	) );
	$wp_customize->add_setting('inc_transition_effect', array(
		'default'					=> 'fade',
		'sanitize_callback'			=> 'inc_sanitize_effect',
		'capability' 				=> 'edit_theme_options'
	));
	$wp_customize->add_control('inc_transition_effect', array(
		'label'						=> __('Transition Effect', 'inc'),
		'section'					=> 'inc_slider_options_setting',
		'active_callback'			=> 'inc_is_enable_slider_set',
		'type'						=> 'select',
		'choices'					=> array(
			'fade'						=> __('Fade','inc'),
			'wipe'						=> __('Wipe','inc'),
			'scrollUp'					=> __('Scroll Up','inc' ),
			'scrollDown'				=> __('Scroll Down','inc' ),
			'scrollLeft'				=> __('Scroll Left','inc' ),
			'scrollRight'				=> __('Scroll Right','inc' ),
			'blindX'					=> __('Blind X','inc' ),
			'blindY'					=> __('Blind Y','inc' ),
			'blindZ'					=> __('Blind Z','inc' ),
			'cover'						=> __('Cover','inc' ),
			'shuffle'					=> __('Shuffle','inc' ),
		),
	));
	$wp_customize->add_setting('inc_transition_delay', array(
		'default'					=> '4',
		'sanitize_callback'			=> 'inc_sanitize_delay_transition',
		'capability' 				=> 'edit_theme_options'
	));
	$wp_customize->add_control('inc_transition_delay', array(
		'label'						=> __('Transition Delay', 'inc'),
		'section'					=> 'inc_slider_options_setting',
		'active_callback'			=> 'inc_is_enable_slider_set',
		'type'						=> 'text',
	) );
	$wp_customize->add_setting('inc_transition_duration', array(
		'default'					=> '1',
		'sanitize_callback'			=> 'inc_sanitize_delay_transition',
		'capability' 				=> 'edit_theme_options'
	));
	$wp_customize->add_control('inc_transition_duration', array(
		'label'						=> __('Transition Length', 'inc'),
		'section'					=> 'inc_slider_options_setting',
		'active_callback'			=> 'inc_is_enable_slider_set',
		'type'						=> 'text',
	) );

	// Section => Slides Options
	$wp_customize->add_section('inc_page_post_slider', array(
		'title'					=> __('Slides Options', 'inc'),
		'panel'					=> 'inc_slider_options'
	) );
	$wp_customize->add_setting('inc_exclude_slider_post', array(
		'default'					=> 0,
		'sanitize_callback'			=> 'inc_sanitize_integer',
		'capability' 				=> 'edit_theme_options'
	));
	$wp_customize->add_control( 'inc_exclude_slider_post', array(
		'label'						=> __('Check to exclude', 'inc'),
		'description'				=> __('Exclude Slider post from Homepage posts?','inc'),
		'section'					=> 'inc_page_post_slider',
		'type'						=> 'checkbox',
	));
	for ( $i=1; $i <= $inc_settings['inc_slider_quantity'] ; $i++ ) {
		$wp_customize->add_setting('inc_featured_post_slider['. $i.']', array(
			'default'					=> '',
			'sanitize_callback'			=>'inc_sanitize_integer',
			'capability' 				=> 'edit_theme_options'
		));
		$wp_customize->add_control( 'inc_featured_post_slider['. $i.']', array(
			'label'						=> __('Add Post/Page ID - Slide #', 'inc') . ' ' . $i,
			'section'					=> 'inc_page_post_slider',
			'settings'					=> 'inc_featured_post_slider['. $i.']',
			'type'						=> 'text',
		));
	}
}
add_action( 'customize_register', 'inc_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function inc_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function inc_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

function inc_customizer_control_scripts() {
	wp_enqueue_style( 'inc-customize-controls', get_template_directory_uri() . '/css/customize-controls.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'inc_customizer_control_scripts', 0 );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function inc_customize_preview_js() {
	wp_enqueue_script( 'inc-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'inc_customize_preview_js' );

/**
 * Sanitize the values
 */
if ( ! function_exists( 'inc_sanitize_choices' ) ) {
	/**
	 * Sanitization: select
	 *
	 * @since 1.1.1
	 *
	 * @param WP_Customize_Setting $setting Setting instance.
	 *
	 * @return mixed Sanitized value.
	 */
	function inc_sanitize_choices($input, $setting) {

		// Ensure input is a slug.
		$input = sanitize_key($input);

		// Get list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control($setting->id)->choices;

		// If the input is a valid key, return it; otherwise, return the default.
		return (array_key_exists($input, $choices) ? $input : $setting->default);
	}
}

if ( ! function_exists( 'inc_sanitize_integer' ) ) {
	/**
	 * Sanitization: number_absint
	 *
	 * @since 1.1.1
	 *
	 * @param WP_Customize_Setting $setting Setting instance.
	 *
	 * @return int Sanitized number.
	 */
	function inc_sanitize_integer($input) {
		return absint($input);
	}
}

if ( ! function_exists( 'inc_sanitize_phone' ) ) {
	/**
	 * Sanitization: phone number
	 *
	 * @since 1.1.1
	 *
	 * @param WP_Customize_Setting $setting Setting instance.
	 *
	 * @return int Sanitized number.
	 */
	function inc_sanitize_phone($input) {
		$input = preg_replace("/[^() 0-9+-]/", '', $input);
		return $input;
	}
}

if ( ! function_exists( 'inc_sanitize_delay_transition' ) ) {
	/**
	 * Sanitization: integer
	 *
	 * @since 1.1.1
	 *
	 * @param WP_Customize_Setting $setting Setting instance.
	 *
	 * @return int Sanitized.
	 */
	function inc_sanitize_delay_transition($input) {
		if (is_numeric($input)) {
			return absint($input);
		}
	}
}

if ( ! function_exists( 'inc_sanitize_effect' ) ) {
	/**
	 * Sanitization: option
	 *
	 * @since 1.1.1
	 *
	 * @param WP_Customize_Setting $setting Setting instance.
	 *
	 * @return string Sanitized option.
	 */
	function inc_sanitize_effect($input) {
		if (!in_array($input, array('fade', 'wipe', 'scrollUp', 'scrollDown', 'scrollLeft', 'scrollRight', 'blindX', 'blindY', 'blindZ', 'cover', 'shuffle'))) {
			$input = 'fade';
		}
		return $input;
	}
}

if ( ! function_exists( 'inc_sanitize_social_links' ) ) {
	/**
	 * Sanitization: html
	 *
	 * @since 1.1.1
	 *
	 * @param WP_Customize_Setting $setting Setting instance.
	 *
	 * @return string Sanitized content.
	 */
	function inc_sanitize_social_links($input) {
		$input = trim(trim($input), ',');
		$explodedInput = explode(',', $input);

		$output = '';
		foreach ($explodedInput as $key => $inputX) {
			$inputX = trim($inputX);
			if (!empty($inputX)) {
				if ($key === 0) {
					$output .= $inputX;
				} else {
					$output .= ', ' . $inputX;
				}
			}
		}
		return sanitize_textarea_field($output);
	}
}

if ( ! function_exists( 'inc_is_sitelayout_is_wide' ) ) {
	/**
	 * Check if sitelayout is wide.
	 *
	 * @since 1.1.1
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function inc_is_sitelayout_is_wide($control) {

		if ( 'narrow' !== $control->manager->get_setting('inc_site_layout')->value() ) {
			return true;
		} else {
			return false;
		}

	}
}

if ( ! function_exists( 'inc_is_social_profiles_set' ) ) {
	/**
	 * Check if social profiles is set.
	 *
	 * @since 1.1.1
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function inc_is_social_profiles_set($control) {

		if ( '' !== $control->manager->get_setting('inc_social_profiles')->value() ) {
			return true;
		} else {
			return false;
		}

	}
}

if ( ! function_exists( 'inc_is_sitelayout_is_narrow' ) ) {
	/**
	 * Check if sitelayout is narrow.
	 *
	 * @since 1.1.1
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function inc_is_sitelayout_is_narrow($control) {

		if ( 'wide' !== $control->manager->get_setting('inc_site_layout')->value() ) {
			return true;
		} else {
			return false;
		}

	}
}

if ( ! function_exists( 'inc_is_enable_slider_set' ) ) {
	/**
	 * Check if slider is enable.
	 *
	 * @since 1.1.1
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function inc_is_enable_slider_set($control) {

		if ( 0 === $control->manager->get_setting('inc_disable_slider')->value() ) {
			return true;
		} else {
			return false;
		}

	}
}
