<?php
/**
 * Inc functions and definitions
 *
 * This file contains all the functions and it's defination that particularly can't be
 * in other files.
 *
 * @package Inc
 */

/**
 * Default Option
 */
function inc_get_option_defaults() {
	$inc_array_of_default_settings = array(
		'inc_slider_quantity'				=> get_theme_mod('inc_slider_quantity', '4'),
		'inc_transition_effect' 				=> get_theme_mod('inc_transition_effect', 'fade'),
		'inc_transition_delay' 				=> get_theme_mod('inc_transition_delay', '4'),
		'inc_transition_duration' 			=> get_theme_mod('inc_transition_duration', '1'),
		'inc_featured_post_slider'			=> get_theme_mod('inc_featured_post_slider', array()),
		'inc_disable_slider' 				=> get_theme_mod('inc_disable_slider', 1),
		'inc_exclude_slider_post'			=> get_theme_mod('inc_exclude_slider_post', 0),
		'inc_site_layout' 					=> get_theme_mod('inc_site_layout', 'wide'),
		'inc_content_layout' 				=> get_theme_mod('inc_content_layout','right'),
		'inc_nav_uppercase'					=> get_theme_mod('inc_nav_uppercase',0),
		'inc_header_fluid'					=> get_theme_mod('inc_header_fluid',0),
		'inc_social_profiles'				=> get_theme_mod('inc_social_profiles',''),
		'inc_infobar_social'					=> get_theme_mod('inc_infobar_social',0),
		'inc_phone_no'						=> get_theme_mod('inc_phone_no',''),
		'inc_email_id'						=> get_theme_mod('inc_email_id',''),
		'inc_location'						=> get_theme_mod('inc_location',''),
		'inc_location_url'					=> get_theme_mod('inc_location_url',''),
		'inc_skype'							=> get_theme_mod('inc_skype',''),
		'inc_page_title_img'					=> get_theme_mod('inc_page_title_img', ''),
	);
	return apply_filters( 'inc_get_option_defaults', $inc_array_of_default_settings );
}

if ( !function_exists( 'inc_social_profiles' ) ) {
	/**
	 * Functions for Social Profiles.
	 */
	function inc_social_profiles() {
		$inc_settings = inc_get_option_defaults(); ?>

		<div class="social-profiles">
			<ul class="clearfix">
				<?php $social_arr = explode(',',$inc_settings['inc_social_profiles']);
				foreach ($social_arr as $value) { ?>
					<li><a title="<?php esc_attr_e( 'Social Profiles', 'inc' ); ?>" href="<?php echo esc_url(trim($value)); ?>"></a></li>
				<?php } ?>
			</ul>
		</div><!-- .social-profiles -->
	<?php }
}

if ( !function_exists('inc_contact_info') ) {
	/**
	 * Functions for Info bar that display at the top.
	 */
	function inc_contact_info() {
		$inc_settings = inc_get_option_defaults();
		$inc_phone_no = $inc_settings['inc_phone_no'];
		$inc_email_id = $inc_settings['inc_email_id'];
		$inc_location = $inc_settings['inc_location'];
		$inc_skype = $inc_settings['inc_skype'];
		$inc_contact_info = '';

		if ($inc_phone_no != '' || $inc_email_id != '' || $inc_location != '' || $inc_skype != '') {
			$inc_contact_info .= '<div class="contact-info"><button class="contact-info-menu-toggle">' . __('Responsive Menu', 'inc') . '</button><ul class="clearfix">';
			if ($inc_phone_no != '') {
				$inc_contact_info .= '<li><a class="phone-number" title="' . esc_attr__('Call Us', 'inc') . '" href="tel:';
				$inc_contact_info .= preg_replace("/[^0-9+]/", '', $inc_phone_no) . '">';
				$inc_contact_info .= preg_replace("/[^() 0-9+-]/", '', $inc_phone_no);
				$inc_contact_info .= '</a></li>';
			}
			if ($inc_email_id != '') {
				$inc_contact_info .= '<li><a class="email" title="' . esc_attr__('Mail Us', 'inc') . '" href="mailto:';
				$inc_contact_info .= is_email($inc_email_id) . '">';
				$inc_contact_info .= is_email($inc_email_id);
				$inc_contact_info .= '</a></li>';
			}
			if ($inc_location != '') {
				$inc_contact_info .= '<li><a class="address" title="' . esc_attr__('My Location', 'inc') . '" target="_blank" href="';
				$inc_contact_info .= esc_url($inc_settings['inc_location_url']) . '">';
				$inc_contact_info .= esc_html($inc_location);
				$inc_contact_info .= '</a></li>';
			}
			if ($inc_skype != '') {
				$inc_contact_info .= '<li><a class="skype" title="' . esc_attr__('Connect with Us', 'inc') . '" href="skype:';
				$inc_contact_info .= esc_url($inc_skype) . '?chat">';
				$inc_contact_info .= esc_html($inc_skype);
				$inc_contact_info .= '</a></li>';
			}
			$inc_contact_info .= '</ul></div><!-- .contact-info -->';
		}
		echo $inc_contact_info;
	}
}

if ( !function_exists('inc_layout_primary') ) {
	/**
	 * Functions for Sidebars.
	 */
	function inc_layout_primary() {
		$inc_settings = inc_get_option_defaults();
		global $post;

		if ($post) {
			$inc_meta_layout = get_post_meta($post->ID, 'inc_sidebarlayout', true);
		}
		$inc_custom_layout = $inc_settings['inc_content_layout'];

		if ( empty($inc_meta_layout) || is_archive() || is_search() || is_home() ) {
			$inc_meta_layout = 'default';
		}

		if ( 'default' == $inc_meta_layout ) {
			if ( ('right' == $inc_custom_layout) || ('nosidebar' == $inc_custom_layout) ) {
				$class = 'col-lg-8 ';
			}
			elseif ( 'left' == $inc_custom_layout ) {
				$class = 'col-lg-8 order-lg-2 ';
			}
			elseif ( 'fullwidth' == $inc_custom_layout ) {
				$class = 'col-lg-12 ';
			}
		}
		elseif ( ('meta-right' == $inc_meta_layout) || ('meta-nosidebar' == $inc_meta_layout) ) {
			$class = 'col-lg-8 ';
		}
		elseif ( 'meta-left' == $inc_meta_layout ) {
			$class = 'col-lg-8 order-lg-2 ';
		}
		elseif ( 'meta-fullwidth' == $inc_meta_layout ) {
			$class = 'col-lg-12 ';
		}

		echo '<div id="primary" class="' . $class . 'content-area">';

	}
}

if (!function_exists('inc_pass_slider_effect_cycle_parameters')):
	/**
	 *Functions that Passes slider effect  parameters from php files to jquery file.
	 */
	function inc_pass_slider_effect_cycle_parameters() {
		$inc_settings 		= inc_get_option_defaults();
		$transition_effects  	= array('fade', 'wipe', 'scrollUp', 'scrollDown', 'scrollLeft', 'scrollRight', 'blindX', 'blindY', 'blindZ', 'cover', 'shuffle');
		$transition_effect   	= in_array($inc_settings['inc_transition_effect'], $transition_effects) ? $inc_settings['inc_transition_effect'] : 'fade';
		$transition_delay    	= absint($inc_settings['inc_transition_delay']*1000);
		$transition_duration 	= absint($inc_settings['inc_transition_duration']*1000);

		wp_localize_script(
			'inc-slider',
			'inc_slider_value',
			array(
				'transition_effect'   => $transition_effect,
				'transition_delay'    => $transition_delay,
				'transition_duration' => $transition_duration,
			)
		);
	}
endif;


if (!function_exists('inc_featured_sliders')):
	/**
	 * displaying the featured image in home page
	 *
	 */
	function inc_featured_sliders() {
		global $post;
		$inc_settings = inc_get_option_defaults();
		$inc_featured_sliders = '';
		$new_slider_list = array();

		for ($i = 1; $i <= $inc_settings['inc_slider_quantity']; $i++) {
			if (isset($inc_settings['inc_featured_post_slider'][$i]) && $inc_settings['inc_featured_post_slider'][$i] != '' && get_post($inc_settings['inc_featured_post_slider'][$i]) && has_post_thumbnail($inc_settings['inc_featured_post_slider'][$i])) {
				$new_slider_list[$i] = $inc_settings['inc_featured_post_slider'][$i];
			} else {
				$new_slider_list[$i] = '';
			}
		}

		$count_valid_slider = 0;
		for ($i = 1; $i <= count($new_slider_list); $i++) {
			if (isset($new_slider_list[$i]) && $new_slider_list[$i] != '' ) {
				$count_valid_slider += 1;
			}
		}

		if ( !empty($inc_settings['inc_featured_post_slider'])) {
			$get_featured_posts			= new WP_Query(array(
				'posts_per_page'		=> $inc_settings['inc_slider_quantity'],
				'post_type'				=> array('post', 'page'),
				'post__in'				=> $new_slider_list,
				'orderby'				=> 'post__in',
				'ignore_sticky_posts'	=> 1
			));
			$i = 0;
			if ( $get_featured_posts->have_posts() ) {
				$inc_featured_sliders .= '<div class="featured-slider"><div class="slider-cycle">';

				while ( $get_featured_posts->have_posts() ):
					$get_featured_posts->the_post();
					$attachment_id = get_post_thumbnail_id();
					$image_attributes = wp_get_attachment_image_src($attachment_id,'full');
					$i++;
					$title_attribute = get_the_title($post->ID);
					$excerpt = substr( get_the_excerpt(), 0, 150 );
					$displayctrl = ( $count_valid_slider > 1 ) ? ' display-ctrl' : '';
					$inc_featured_sliders .= '<div class="slides' . $displayctrl . '">';
					if ($image_attributes) {
						$inc_featured_sliders .= '<div class="slider"' . ' style="background-image:url(' . "'" .esc_url($image_attributes[0]) . "'" . ');">';
					} else {
						$inc_featured_sliders .= '<div class="slider">';
					}
					if ($title_attribute != '' || $excerpt != '') {
						$inc_featured_sliders .= '<div class="container"><div class="featured-content"><div class="content-inner">';
						if ($title_attribute != '') {
							$inc_featured_sliders .= '<h2 class="featured-title"><a href="' . esc_url(get_permalink()) . '" title="' . the_title_attribute('echo=0') . '">' . get_the_title() . '</a></h2><!-- .featured-title -->';
						}
						if ($excerpt != '') {
							$inc_featured_sliders .= '<p>' . $excerpt . '</p>';
						}
						$inc_featured_sliders .= '<div class="btn-section">';
						$inc_featured_sliders .= '<a href="' . esc_url(get_permalink()) . '" class="btn btn-theme btn-lg btn-rounded">' . esc_html__('Read More', 'inc') . '</a>';
						$inc_featured_sliders .= '</div><!-- .btn-section -->';
						$inc_featured_sliders .= '</div><!-- .content-inner --></div><!-- .featured-content --></div><!-- .container -->';
					}
					$inc_featured_sliders .= '</div><!-- .slider --></div><!-- .slides -->';
				endwhile;

				wp_reset_postdata();
				$inc_featured_sliders .= '</div><!-- .slider-cycle -->';
				if ( $count_valid_slider > 1 ) {
					$inc_featured_sliders .= '<a class="fs-prev" href="#">' . esc_html__('Prev', 'inc') . '</a><a class="fs-next" href="#">' . esc_html__('Next', 'inc') . '</a>';
				}
				$inc_featured_sliders .= '</div> <!-- .featured-slider -->';
			}
		}
		echo $inc_featured_sliders;
	}
endif;
