<?php
 /**
 * Register widget area and Sidebar.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 *
 * @package Inc
 */
/****************************************************************************************/

/**
 * Function to register the widget areas(sidebar) and widgets.
 */
function inc_widgets_init() {

	// Registering Left Sidebar
	register_sidebar( array(
		'name' 				=> __('Left Sidebar', 'inc') ,
		'id' 				=> 'inc_left_sidebar',
		'description' 		=> __('Shows widgets at Left Side.', 'inc'),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s">',
		'after_widget' 		=> '</section>',
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>',
	)	);

	// Registering Right Sidebar
	register_sidebar( array(
		'name' 				=> __('Right Sidebar', 'inc') ,
		'id' 				=> 'inc_right_sidebar',
		'description' 		=> __('Shows widgets at Right Side.', 'inc'),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s">',
		'after_widget' 		=> '</section>',
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>',
	) );

	// Registering Business Page template sidebar
	register_sidebar(array(
		'name' 				=> __('Business Page Section', 'inc') ,
		'id' 				=> 'inc_business_page_sidebar',
		'description' 		=> __('Shows widgets on Business Page Template. Suitable widget: TH: Featured/Recent Post, TH: Featured Clients/Products, TH: Featured Page, TH: Our Team, TH: PromoBox, TH: Services and TH: Testimonial', 'inc'),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s">',
		'after_widget' 		=> '</section>',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>',
	));

	// Registering Footer Sidebar 1
	register_sidebar( array(
		'name' 				=> __('Footer - Column 1', 'inc') ,
		'id' 				=> 'inc_footer_sidebar',
		'description' 		=> __('Shows widgets at Footer Column 1.', 'inc'),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s">',
		'after_widget' 		=> '</section>',
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>',
	) );

	// Registering Footer Sidebar 2
	register_sidebar( array(
		'name' 				=> __('Footer - Column 2', 'inc'),
		'id' 				=> 'inc_footer_column2',
		'description' 		=> __('Shows widgets at Footer Column 2.', 'inc'),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s">',
		'after_widget' 		=> '</section>',
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>',
	) );

	// Registering Footer Sidebar 3
	register_sidebar( array(
		'name' 				=> __('Footer - Column 3', 'inc'),
		'id' 				=> 'inc_footer_column3',
		'description' 		=> __('Shows widgets at Footer Column 3.', 'inc'),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s">',
		'after_widget' 		=> '</section>',
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>',
	) );

	register_widget("inc_service_widget");
	register_widget("inc_Widget_featured_page");
	register_widget("inc_promobox_widget");
	register_widget("inc_ourteam_widget");
	register_widget("inc_Widget_Testimonial");
	register_widget("inc_Widget_featured_post");
	register_widget("inc_Widget_recent_post");
}
add_action('widgets_init', 'inc_widgets_init');


/****************************************************************************************/
/**
 * Widget for Business Page Template.
 * Construct the widget.
 * i.e. Name, description and control options.
 */
class inc_service_widget extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'classname' => 'inc-widget-services',
			'description' => __('Display Services', 'inc')
		);
		parent::__construct(false, $name = __('TH: Services', 'inc') , $widget_ops);
	}

	function form($instance) {

		$instance = wp_parse_args(
			(array) $instance,
			array(
				'checkbox_smallview' => '',
				'service_title'=>'',
				'page_id0' => '',
				'page_id1' => '',
				'page_id2' => '',
				'page_id3' => '',
				'page_id4' => '',
				'page_id5' => '',
			)
		); ?>
		<p>
			<?php esc_html_e('Set Featured Image for Service Icon/Image on the related pages if you need to display it.', 'inc'); ?>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('service_title'); ?>">
				<?php esc_html_e('Title: ', 'inc'); ?>
			</label>
			<input id="<?php echo $this->get_field_id('service_title'); ?>" name="<?php echo $this->get_field_name('service_title'); ?>" type="text" value="<?php echo esc_attr($instance['service_title']); ?>"/>
		</p>
		<p>
			<input id="<?php echo $this->get_field_id('checkbox_smallview'); ?>" name="<?php echo $this->get_field_name('checkbox_smallview'); ?>" type="checkbox" value="1" <?php checked( '1', absint($instance['checkbox_smallview']) ); ?>/>
			<label for="<?php echo $this->get_field_id('checkbox_smallview'); ?>">
				<?php esc_html_e('Check to display small image','inc'); ?>
			</label>
		</p>
		<?php for ($i = 0; $i < 6; $i++) {
			$page_id = 'page_id' . $i; ?>
			<p>
				<label for="<?php echo $this->get_field_id($page_id); ?>">
					<?php esc_html_e('Page: ', 'inc'); ?>
				</label>
				<?php wp_dropdown_pages(
					array(
						'show_option_none' => ' ',
						'name' => $this->get_field_name($page_id) ,
						'selected' => $instance[$page_id]
					)
				); ?>
			</p>
		<?php }
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['checkbox_smallview'] = absint($new_instance['checkbox_smallview']);
		$instance['service_title'] = sanitize_text_field($new_instance['service_title']);
		for ($i = 0; $i < 6; $i++) {
			$var = 'page_id' . $i;
			$instance[$var] = absint($new_instance[$var]);
		}
		return $instance;
	}

	function widget($args, $instance) {

		$checkbox_smallview = empty($instance['checkbox_smallview']) ? '' : $instance['checkbox_smallview'];
		$service_title = empty($instance['service_title']) ? '' : $instance['service_title'];
		global $post;

		$page_array = array();
		for ($i = 0; $i < 6; $i++) {
			$var = 'page_id' . $i;
			$page_id = isset($instance[$var]) ? $instance[$var] : '';

			if (!empty($page_id)) {
				array_push($page_array, $page_id);
			}
		}
		$get_featured_pages = new WP_Query(
			array(
			'posts_per_page' => 6,
			'post_type' => array('page'),
			'post__in' => $page_array,
			'orderby' => 'post__in',
			'ignore_sticky_posts' => 1
			)
		);

		echo $args['before_widget']; ?>

			<div class="container">
				<?php if( !empty($service_title) ) { ?>
					<h2 class="widget-title"><?php echo esc_html($service_title); ?></h2>
				<?php } ?>
				<div class="row justify-content-center<?php echo ($checkbox_smallview == true) ? " small-featured-img" : ''; ?>">
					<?php $i = 0;
					while ($get_featured_pages->have_posts()):$get_featured_pages->the_post(); ?>
						<div class="col-md-6 col-lg-4 services-col">
							<div class="service-wrap">
								<?php if ( has_post_thumbnail() ) { ?>
									<div class="service-img">
										<a href="<?php the_permalink(); ?>"><?php echo get_the_post_thumbnail( $post->ID); ?></a>
									</div>
								<?php } ?>
								<div class="service-content">
									<?php the_title( '<h3 class="service-title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h3>' );
									$excerpt = get_the_excerpt();
									if ($excerpt != '') {
										if (strlen($excerpt) > 125) { ?>
											<article>
												<p><?php echo substr($excerpt, 0, 125) . esc_html('...'); ?></p>
											</article>
											<a href="<?php echo esc_url(get_permalink()); ?>" class="btn btn-outline-theme more-link">
												<?php esc_html_e('Read More', 'inc'); ?>
											</a>
										<?php } else { ?>
											<article>
												<p><?php echo $excerpt; ?></p>
											</article>
										<?php }
									} ?>
								</div><!-- .service-content -->
							</div><!-- .service-wrap -->
						</div><!-- .col-md-6 .col-lg-4 .services-col -->
						<?php $i++;
					endwhile;
					// Reset Post Data
					wp_reset_postdata(); ?>
				</div><!-- .row -->
			</div><!-- .container -->

		<?php echo $args['after_widget'] . '<!-- .widget_services -->';
	}
}

/****************************************************************************************/
/**
 * Widget for Business Page Template.
 * Construct the widget.
 * i.e. Pages and control options.
 */
class inc_Widget_featured_page extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'classname' => 'inc-widget-featured-page',
			'description' => __('Display Featured Page', 'inc')
		);
		parent::__construct(false, $name = __('TH: Featured Page', 'inc') , $widget_ops);
	}

	function form($instance) {

		$instance = wp_parse_args(
			(array) $instance,
			array(
				'featured_display' => 1,
				'page_id' => '',
			)
		);

		$featured_display = ( isset($instance['featured_display']) && is_numeric($instance['featured_display']) ) ? (int) $instance['featured_display'] : 1; ?>
		<p>
			<?php esc_html_e('Set Featured Image on the related page if you need to display Image.', 'inc'); ?>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('featured_display'); ?>">
				<?php esc_html_e('Display Content:','inc'); ?>
			</label>
			<input type="radio" id="<?php echo ($this->get_field_id('featured_display') . '-1'); ?>" name="<?php echo ($this->get_field_name('featured_display')); ?>" value="1" <?php checked($featured_display == 1, true); ?>>
			<label for="<?php echo ($this->get_field_id('featured_display') . '-1'); ?>" class="input-label"><?php esc_html_e('Left', 'inc'); ?></label>
			<input type="radio" id="<?php echo ($this->get_field_id( 'featured_display') . '-2'); ?>" name="<?php echo ($this->get_field_name('featured_display')); ?>" value="2" <?php checked($featured_display == 2, true); ?>>
			<label for="<?php echo ($this->get_field_id('featured_display') . '-2'); ?>" class="input-label"><?php esc_html_e('Right', 'inc'); ?></label>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('page_id'); ?>">
				<?php esc_html_e('Page: ', 'inc'); ?>
			</label>
			<?php wp_dropdown_pages(
				array(
					'show_option_none' => ' ',
					'name' => $this->get_field_name('page_id') ,
					'selected' => $instance['page_id']
				)
			); ?>
		</p>
		<?php
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['featured_display'] = ( isset($new_instance['featured_display']) && $new_instance['featured_display'] > 0 && $new_instance['featured_display'] < 3 ) ? (int) $new_instance['featured_display'] : 0;
		$instance['page_id'] = absint($new_instance['page_id']);
		return $instance;
	}

	function widget($args, $instance) {
		$featured_display = ( isset($instance['featured_display']) && is_numeric($instance['featured_display']) ) ? (int) $instance['featured_display'] : 1;
		$page_id = isset($instance['page_id']) ? $instance['page_id'] : '';
		global $post;

		$page_array = array();
		if (!empty($page_id)) {
			array_push($page_array, $page_id);
		}
		$get_featured_pages = new WP_Query(
			array(
				'posts_per_page' => 1,
				'post_type' => array('page'),
				'post__in' => $page_array,
				'orderby' => 'post__in'
			)
		);

		echo $args['before_widget'];

		while ($get_featured_pages->have_posts()):
			$get_featured_pages->the_post(); ?>
			<div class="container">
				<div class="row gutter-50 align-items-center text-lg-left">
					 <div class="col-lg-6<?php echo ($featured_display == 2) ? ' order-lg-2' : ''; echo ($featured_display == 2 && !has_post_thumbnail()) ? ' offset-lg-6' : ''; ?>">
						<div class="featured-page-content">
							<?php the_title( '<h2 class="widget-title">', '</h2>' );
							the_excerpt(); ?>
							<a href="<?php the_permalink(); ?>" class="btn btn-outline-theme btn-rounded"><?php esc_html_e('Read More','inc'); ?></a>
						</div>
					 </div>
					<?php if (has_post_thumbnail()) { ?>
						<div class="col-lg-6<?php echo ($featured_display == 2) ? ' order-lg-1' : ''; ?>">
							<div class="featured-page-image">
								<figure>
									<?php $url = wp_get_attachment_url( get_post_thumbnail_id($post->ID) ); ?>
									<img alt="<?php the_title_attribute(); ?>" src="<?php echo esc_url($url); ?>">
								</figure>
							</div>
						</div>
					<?php } ?>
				</div>
			</div><!-- .container -->
		<?php endwhile;

		wp_reset_postdata();

		echo $args['after_widget'] . '<!-- .widget_featured_page -->';
	}
}

/**************************************************************************************/
/**
 * Widget for Business Page Template.
 * Construct the widget.
 * i.e. Descriptions, images, button and control options.
 */
class inc_promobox_widget extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'classname' => 'inc-widget-promotional-bar',
			'description' => __('Display Promotional Bar', 'inc')
		);
		parent::__construct(false, $name = __('TH: PromoBox', 'inc'), $widget_ops);
	}

	function form($instance) {
		$instance = wp_parse_args(
			(array) $instance,
			array(
				'inc_promotional_inline' => 0,
				'page_id' => '',
				'inc_btn' => '',
				'inc_btn_url' => ''
			)
		); ?>
		<p>
			<?php esc_html_e('Set Featured Image on the related page if you need to display Background Image.', 'inc'); ?>
		</p>
		<p>
			<input id="<?php echo $this->get_field_id('inc_promotional_inline'); ?>" name="<?php echo $this->get_field_name('inc_promotional_inline'); ?>" type="checkbox" value="1" <?php checked( '1', absint($instance['inc_promotional_inline']) ); ?>/>
			<label for="<?php echo $this->get_field_id('inc_promotional_inline'); ?>">
				<?php esc_html_e('Inline Layout','inc'); ?>
			</label>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('page_id'); ?>">
				<?php esc_html_e('Page:', 'inc'); ?>
			</label>
			<?php wp_dropdown_pages(
				array(
					'show_option_none' => ' ',
					'name' => $this->get_field_name('page_id') ,
					'selected' => $instance['page_id']
				)
			); ?>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('inc_btn'); ?>">
				<?php esc_html_e('Button:', 'inc'); ?>
			</label>
			<input id="<?php echo $this->get_field_id('inc_btn'); ?>" name="<?php echo $this->get_field_name('inc_btn'); ?>" type="text" value="<?php echo esc_attr($instance['inc_btn']); ?>"/>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('inc_btn_url'); ?>">
				<?php esc_html_e('Button Url:', 'inc'); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id('inc_btn_url'); ?>" name="<?php echo $this->get_field_name('inc_btn_url'); ?>" type="text" value="<?php echo esc_url($instance['inc_btn_url']); ?>"/>
		</p>
		<?php
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['inc_promotional_inline'] = absint($new_instance['inc_promotional_inline']);
		$instance['page_id'] = absint($new_instance['page_id']);
		$instance['inc_btn'] = sanitize_text_field($new_instance['inc_btn']);
		$instance['inc_btn_url'] = esc_url_raw($new_instance['inc_btn_url']);
		return $instance;
	}

	function widget($args, $instance) {
		$inc_promotional_inline = empty($instance['inc_promotional_inline']) ? '' : $instance['inc_promotional_inline'];
		$page_id = isset($instance['page_id']) ? $instance['page_id'] : '';
		$inc_btn = empty($instance['inc_btn']) ? '' : $instance['inc_btn'];
		$inc_btn_url = empty($instance['inc_btn_url']) ? '' : $instance['inc_btn_url'];
		global $post;

		$page_array = array();
		if (!empty($page_id)) {
			array_push($page_array, $page_id);
		}

		$get_featured_pages = new WP_Query(
			array(
				'posts_per_page' => 1,
				'post_type' => array('page'),
				'post__in' => $page_array,
				'orderby' => 'post__in'
			)
		);

		echo $args['before_widget'];

		while ($get_featured_pages->have_posts()):
			$get_featured_pages->the_post(); ?>
			<div class="promotional_bar_content<?php echo ($inc_promotional_inline == 1) ? ' promotional-bar-inline' : '' ;?>"<?php if ( has_post_thumbnail() ) { ?> style="background-image:url('<?php echo esc_url( wp_get_attachment_url(get_post_thumbnail_id($post->ID)) ); ?>');"<?php } ?>>
				<div class="container">
					<div class="row align-items-center justify-content-center">
						<div class="<?php echo ($inc_promotional_inline == 1) ? 'col-lg' : 'col-lg-10' ;?>">
							<?php the_title( '<h2 class="promo-title">', '</h2>' );
							the_excerpt(); ?>
						</div>
						<?php if ( !empty($inc_btn) && !empty($inc_btn_url) ) { ?>
							<div class="<?php echo ($inc_promotional_inline == 1) ? 'col-lg-auto' : 'col-lg-10' ;?>">
								<div class="btn-section">
									<a class="btn btn-light btn-lg" href="<?php echo esc_url($inc_btn_url); ?>" title="<?php echo esc_attr($inc_btn); ?>"><?php echo esc_html($inc_btn); ?></a>
								</div>
							</div>
						<?php } ?>
					</div><!-- .row -->
				</div><!-- .container -->
			</div><!-- .promotional_bar_content -->
		<?php endwhile;

		wp_reset_postdata();

		echo $args['after_widget'] . '<!-- .widget_promotional_bar -->';
	}
}

/**************************************************************************************/
/**
 * Widget for Business Page Template.
 * Construct the widget.
 * i.e. Name, description, images and control options.
 */
class inc_ourteam_widget extends WP_Widget {

	function __construct() {
		$widget_ops = array( 
			'classname' => 'inc-widget-our-team',
			'description' => __( 'Display Our Team', 'inc' )
		);
		parent::__construct( false, $name = __( 'TH: Our Team', 'inc' ), $widget_ops);
	}

	function form($instance) {
		$instance = wp_parse_args(
			(array) $instance,
			array(
				'title' => '',
				'page_id0' => '',
				'page_id1' => '',
				'page_id2' => '',
				'designation0' => '',
				'designation1' => '',
				'designation2' => '',
			)
		); ?>
		<p>
			<?php esc_html_e('Set Featured Image for Photo on the related page if you need to display Photo.', 'inc'); ?>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">
				<?php esc_html_e('Title:', 'inc'); ?>
			</label>
			<input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($instance['title']); ?>"/>
		</p>
		<?php for ( $i = 0; $i <= 2; $i++ ) {
			$page_id = 'page_id'.$i;
			$designation = 'designation'.$i; ?>

			<h4 class="section-header">
				<?php esc_html_e('Team: ', 'inc'); echo esc_html($i+1); ?>
			</h4>
			<p>
				<label for="<?php echo $this->get_field_id($page_id); ?>">
					<?php esc_html_e('Team Page:', 'inc'); ?>
				</label>
				<?php wp_dropdown_pages(
					array(
						'show_option_none' => ' ',
						'name' => $this->get_field_name($page_id),
						'selected' => $instance[$page_id]
					)
				); ?>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('designation'); ?>">
					<?php esc_html_e('Designation:', 'inc'); ?>
				</label>
				<input id="<?php echo $this->get_field_id($designation); ?>" name="<?php echo $this->get_field_name($designation); ?>" type="text" value="<?php echo esc_attr($instance[$designation]); ?>"/>
			</p>
			<?php
		} ?>
		<?php
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field($new_instance['title']);
		for( $i = 0; $i <= 2; $i++ ) {
			$page_id = 'page_id' . $i;
			$instance[$page_id] = absint($new_instance[$page_id]);
			$designation = 'designation'.$i;
			$instance[$designation] = sanitize_text_field($new_instance[$designation]);
		}
		return $instance;
	}

	function widget($args, $instance) {
		$title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
		$page_id_array = array();
		$designation_array = array();
		global $post;

		for ($i = 0; $i <= 2; $i++) {
			$page_id = 'page_id' . $i;
			$page_id = isset($instance[$page_id]) ? $instance[$page_id] : '';
			$designation = 'designation' . $i;
			$designation = isset($instance[$designation]) ? $instance[$designation] : '';

			if ( !empty($page_id) || !empty($designation) ) {
				if (!empty($designation)) array_push($designation_array, $designation);
				else array_push($designation_array, "");
				if (!empty($page_id)) array_push($page_id_array, $page_id);
				else array_push($page_id_array, "");
			}
		}

		$valid_page_index = array();
		for ($i = 0; $i <= 2; $i++) {
			if (!empty($page_id_array[$i])) {
				$valid_page_index[] = $i;
			}
		}

		$get_featured_pages = new WP_Query(
			array(
				'posts_per_page' => 3,
				'post_type' => array('page'),
				'post__in' => $page_id_array,
				'orderby' => 'post__in'
			)
		);

		echo $args['before_widget']; ?>

		<div class="container">
			<?php if ( !empty($title) ) {
				echo $args['before_title'] . esc_html($title) . $args['after_title'];
			} ?>
			<div class="row justify-content-center">
				<?php if (!empty($page_id_array)) {
					$i = 0;
				}
				while ($get_featured_pages->have_posts()):
					$get_featured_pages->the_post(); ?>
					<div class="col-md-4">
						<div class="team-block">
							<?php if ( has_post_thumbnail() ) { ?>
								<div class="team-img" style="background-image:url('<?php echo esc_url( wp_get_attachment_url(get_post_thumbnail_id($post->ID)) ); ?>');"></div>
							<?php } ?>
							<div class="team-info-section">
								<?php the_title( '<h3 class="team-member-name">', '</h3>' );
								if ( !empty($page_id_array) && !empty($designation_array[$valid_page_index[$i]]) ) { ?>
									<h5 class="team-member-designation"><?php echo esc_html($designation_array[$valid_page_index[$i]]); ?></h5>
								<?php } ?>
							</div><!-- .team-info-section -->
						</div><!-- .team-block -->
					</div>
					<?php if (!empty($page_id_array)) {
						$i++;
					}
				endwhile;
				wp_reset_postdata(); ?>
			</div><!-- .row .justify-content-center -->
		</div><!-- .container -->

		<?php echo $args['after_widget'] . '<!-- .widget_our_team -->';
	}
}

/**************************************************************************************/
/**
 * Widget for Business Page Template.
 * Construct the widget.
 * i.e. Name, description, images and control options.
 */
class inc_Widget_Testimonial extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'classname' => 'inc-widget-testimonial',
			'description' => __('Display Testimonial', 'inc')
		);
		parent::__construct(false, $name = __('TH: Testimonial', 'inc') , $widget_ops);
	}

	function form($instance) {
		$instance = wp_parse_args(
			(array) $instance,
			array(
				'title' => '',
				'page_id0' => '',
				'page_id1' => '',
				'designation0' => '',
				'designation1' => ''
			)
		); ?>
		<p>
			<?php esc_html_e('Set Content for Testimonial and Set Featured Image for Photo on the related page if you need to display Photo.', 'inc'); ?>
		</p>
		<p>
		  	<label for="<?php echo $this->get_field_id('title'); ?>">
				<?php esc_html_e('Title:', 'inc'); ?>
			</label>
			<input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($instance['title']); ?>"/>
		</p>

		<?php
		for ($i = 0; $i <= 1; $i++) {
			$page_id = 'page_id' . $i;
			$designation = 'designation' . $i; ?>

			<h4 class="section-header">
				<?php esc_html_e('Testimonial: ', 'inc'); echo esc_html($i+1); ?>
			</h4>
			<p>
				<label for="<?php echo $this->get_field_id($page_id); ?>">
					<?php esc_html_e('Testimonial Page :', 'inc'); ?>
				</label>
				<?php wp_dropdown_pages(
					array(
						'show_option_none' => ' ',
						'name' => $this->get_field_name($page_id),
						'selected' => $instance[$page_id]
					)
				); ?>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id($designation); ?>">
					<?php esc_html_e('Designation: ', 'inc'); ?>
				</label>
				<input id="<?php echo $this->get_field_id($designation); ?>" name="<?php echo $this->get_field_name($designation); ?>" type="text" value="<?php echo esc_attr($instance[$designation]); ?>"/>
			</p>
		<?php }
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field($new_instance['title']);
		for ($i = 0; $i <= 1; $i++) {
			$page_id = 'page_id' . $i;
			$instance[$page_id] = absint($new_instance[$page_id]);
			$designation = 'designation' . $i;
			$instance[$designation] = sanitize_text_field($new_instance[$designation]);
		}
		return $instance;
	}

	function widget($args, $instance) {
		$title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
		$page_id_array = array();
		$page_id_count = 0;
		$designation_array = array();
		$designation_count = 0;
		global $post;

		for ($i = 0; $i <= 1; $i++) {
			$page_id = 'page_id' . $i;
			$page_id = isset($instance[$page_id]) ? $instance[$page_id] : '';
			$designation = 'designation' . $i;
			$designation = isset($instance[$designation]) ? $instance[$designation] : '';

			if ( !empty($page_id) || !empty($designation) ) {
				if (!empty($designation)) array_push($designation_array, $designation);
				else array_push($designation_array, "");
				if (!empty($page_id)) array_push($page_id_array, $page_id);
				else array_push($page_id_array, "");
			}
		}

		$valid_page_index = array();
		for ($i = 0; $i <= 2; $i++) {
			if (!empty($page_id_array[$i])) {
				$valid_page_index[] = $i;
			}
		}

		for ($i = 0; $i <= 1; $i++) {
			if (!empty($designation_array[$i])) {
				$designation_count += 1;
			}
			if (!empty($page_id_array[$i])) {
				$page_id_count += 1;
			}
		}

		$get_featured_pages = new WP_Query(
			array(
				'posts_per_page' => 2,
				'post_type' => array('page'),
				'post__in' => $page_id_array,
				'orderby' => 'post__in'
			)
		);

		echo $args['before_widget']; ?>

		<div class="container">
			<?php if ( !empty($title) ) {
				echo $args['before_title'] . esc_html($title) . $args['after_title'];
			} ?>
			<div class="testimonial-box row justify-content-center">
				<?php if (!empty($page_id_array)) {
					$i = 0;
				}
				while ($get_featured_pages->have_posts()):
					$get_featured_pages->the_post(); ?>
					<div class="testimonial-block<?php echo ( $page_id_count >= 2 || $page_id_count == 0 ) ? ' col-md-6' : ' col-md-10' ?>">
						<?php if ( get_post()->post_content !== '' ) { ?>
							<div class="testimonial-content">
								<?php the_content(); ?>
							</div>
						<?php } ?>
						<div class="testimonial-meta">
							<?php if ( has_post_thumbnail() ) { ?>
								<div class="testimonial-img" style="background-image:url('<?php echo esc_url( wp_get_attachment_url(get_post_thumbnail_id($post->ID)) ); ?>');"></div>
							<?php } ?>
							<?php the_title( '<h3 class="testimonial-writer">', '</h3>' );
							if ( !empty($page_id_array) && !empty($designation_array[$valid_page_index[$i]]) ) { ?>
								<h4 class="designation">
									<?php echo esc_html($designation_array[$valid_page_index[$i]]); ?>
								</h4>
							<?php } ?>
						</div><!-- .testimonail-meta -->
					</div><!-- .testimonial-block -->
					<?php if (!empty($page_id_array)) {
						$i++;
					}
				endwhile;
				wp_reset_postdata(); ?>
			</div><!-- .testimonial-box -->
		</div><!-- .container -->

		<?php echo $args['after_widget'] . '<!-- .widget_testimonial -->';
	}
}

/****************************************************************************************/
/**
 * Widget for Business Page Template.
 * Construct the widget.
 * i.e. Posts.
 */
class inc_Widget_featured_post extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'classname' => 'inc-widget-featured-post',
			'description' => __('Display Featured/Recent Post', 'inc')
		);
		parent::__construct(false, $name = __('TH: Featured/Recent Post', 'inc') , $widget_ops);
	}

	function form($instance) {

		$instance = wp_parse_args(
			(array) $instance,
			array(
				'category' => ''
			)
		); ?>
		<p>
			<?php esc_html_e('Set Featured Image on the related page if you need to display Image.', 'inc'); ?>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('category'); ?>">
				<?php esc_html_e('Category:', 'inc'); ?>
			</label>
			<?php wp_dropdown_categories(
				array(
					'show_option_none' => ' ',
					'name' => $this->get_field_name('category') ,
					'selected' => $instance['category']
				)
			); ?>
		</p>
		<?php
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['category'] = absint($new_instance['category']);
		return $instance;
	}

	function widget($args, $instance) {

		$category = isset($instance['category']) ? $instance['category'] : '';
		global $post;

		$get_featured_posts = new WP_Query(
			array(
				'posts_per_page' => 2,
				'post_type' => array('post'),
				'category__in' => $category,
			)
		);

		$category_count = '';
		if ( get_category($category) !== '' ) {
			$category_count = get_category($category)->category_count;
		}

		echo $args['before_widget']; ?>
			<div class="container-fluid">
				<div class="row justify-content-center">
					<?php while ($get_featured_posts->have_posts()):$get_featured_posts->the_post(); ?>
						<div class="<?php echo ($category_count == 1) ? 'col-12 ' : 'col-lg-6 '; ?>featured-post-col">
							<div class="featured-post">
								<div class="featured-post-content">
									<?php if ( !( has_post_format('link') || has_post_format('quote') ) ) { ?>
										<div class="entry-meta entry-meta-first">
											<div class="date styled-date">
												<span class="day"><?php echo esc_html(get_the_date('j')); ?></span>
												<?php echo esc_html(get_the_date('F, Y')); ?>
											</div><!-- .date -->
										</div><!-- .entry-meta -->
									<?php }
									if ( !has_post_format('quote') ) {
										the_title( '<h3 class="featured-post-title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h3>' );
									}
									 if ( !( has_post_format('link') || has_post_format('quote') ) ) {
									 	$excerpt = get_the_excerpt();
										if ( $excerpt !='' ) { ?>
											<?php if ( strlen($excerpt) > 125 ) { ?>
												<article>
													<p><?php echo substr($excerpt, 0 , 125) . '&hellip;'; ?></p>
												</article>
												<a href="<?php echo esc_url(get_permalink()); ?>" class="btn btn-outline-dark btn-rounded more-link"><?php esc_html_e('Read More','inc'); ?></a>
											<?php } else { ?>
												<article>
													<p><?php echo $excerpt; ?></p>
												</article>
											<?php }
										}
									} else {
										the_content();
									} ?>
								</div><!-- .featured-post-content -->
								<?php if ( has_post_thumbnail() ) { ?>
									<div class="featured-post-img">
										<?php if ( !has_post_format('quote') ) { ?>
											<a href="<?php the_permalink(); ?>"><?php echo get_the_post_thumbnail($post->ID); ?></a>
										<?php } else {
											echo get_the_post_thumbnail($post->ID);
										} ?>
									</div>
								<?php } ?>
							</div><!-- .featured-post -->
						</div><!-- .featured-post-col -->
					<?php endwhile;
					// Reset Post Data
					wp_reset_query(); ?>
				</div><!-- .row -->
			</div><!-- .container-fluid -->

		<?php echo $args['after_widget'] . '<!-- .widget_featured_post -->';
	}
}

/****************************************************************************************/
/**
 * Widget for Any Sidebars.
 * Construct the widget.
 * i.e. Name and posts.
 */
class inc_Widget_recent_post extends WP_Widget {
	function __construct() {
		$widget_ops = array(
			'classname' => 'inc-widget-recent-post',
			'description' => __('Display Recent Post', 'inc')
		);
		parent::__construct(false, $name = __('TH: Recent Post', 'inc') , $widget_ops);
	}
	function form($instance) {
		$instance = wp_parse_args(
			(array) $instance,
			array(
				'number' => '5',
				'service_title' => '',
			)
		); ?>

		<p>
			<label for="<?php echo $this->get_field_id('service_title'); ?>">
				<?php esc_html_e('Title:', 'inc'); ?>
			</label>
			<input id="<?php echo $this->get_field_id('service_title'); ?>" name="<?php echo $this->get_field_name('service_title'); ?>" type="text" value="<?php echo esc_attr($instance['service_title']); ?>"/>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('number'); ?>">
			<?php esc_html_e( 'Number of Post:', 'inc' ); ?>
			</label>
			<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo absint($instance[ 'number']); ?>" size="3"/>
		</p>
		<?php
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['number'] = absint( $new_instance['number'] );
		$instance['service_title'] = sanitize_text_field($new_instance['service_title']);
		return $instance;
	}

	function widget($args, $instance) {

		$service_title = empty($instance['service_title']) ? '' : $instance['service_title'];
		$number = empty($instance['number']) ? 5 : $instance['number'];
		global $post;

		$get_featured_posts = new WP_Query(
			array(
				'posts_per_page' => $number,
				'post_type' => array('post'),
				'ignore_sticky_posts' => 1
			)
		);

		echo $args['before_widget']; ?>

			<div class="container">
				<?php if (!empty($service_title)){ ?>
					<h2 class="widget-title"><?php echo esc_html($service_title);?></h2>
				<?php } ?>
				<?php if ($number > 0) {
					$i = 0;
					while ($get_featured_posts->have_posts()):$get_featured_posts->the_post(); ?>
						<div class="recent-post">
							<?php if ( has_post_thumbnail() ){ ?>
								<div class="recent-post-img">
									<a class="post-img" href="<?php the_permalink(); ?>" style="background-image: url('<?php echo get_the_post_thumbnail_url($post->ID); ?>');"></a>
								</div>
							<?php } ?>
							<div class="recent-post-content">
								<?php the_title( '<h4 class="recent-post-title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h4>' );
								if ( !has_post_format('link') ) { ?>
									<div class="entry-meta">
										<div class="author">
											<span class="label"><?php esc_html_e('by', 'inc'); ?></span>
											<?php inc_posted_author(); ?>
										</div><!-- .author -->
										<div class="date">
											<?php echo esc_html(get_the_date('j M Y')); ?>
										</div><!-- .date -->
									</div><!-- .entry-meta -->
								<?php } ?>
							</div><!-- .recent-post-content -->
						</div><!-- .recent-post -->
						<?php $i++;
					endwhile;
					// Reset Post Data
					wp_reset_postdata();
				} ?>
			</div><!-- .container -->

		<?php echo $args['after_widget'] . '<!-- .widget_recent_post -->';
	}
}
